@@ -22,7 +22,7 @@ extend it with animation and glsl shader features.
 the class :class:`AnimatedOnboardingTour` is providing an app onboarding tour that covers the core features and can be
 easily extended with app-specific tour pages.
 
-finally, the class :class:`TourOverlay` is implementing a overlay layout widget to display the animations, shaders,
+finally, the class :class:`TourOverlay` is implementing an overlay layout widget to display the animations, shaders,
 tour page texts, tooltip text and the navigation buttons of an active/running app tour.
 
 
@@ -72,7 +72,7 @@ the screen/window size is not big enough then the tooltip texts get scrollable.
 help behaviour mixin
 ====================
 
-to show a i18n translatable help text for a Kivy widget create either a sub-class of the widget. the following example
+to show a i18n translatable help text for a Kivy widget create either a subclass of the widget. the following example
 allows to attach a help text to a Kivy :class:`~kivy.uix.button.Button`::
 
     from kivy.uix.button import Button
@@ -151,7 +151,7 @@ from kivy.uix.textinput import TextInput
 from kivy.uix.widget import Widget                                                                      # type: ignore
 
 from ae.base import snake_to_camel                                                                      # type: ignore
-from ae.inspector import try_eval                                                                       # type: ignore
+from ae.dynamicod import try_eval                                                                       # type: ignore
 from ae.gui_help import (                                                                               # type: ignore
     REGISTERED_TOURS, anchor_layout_x, anchor_layout_y, anchor_points, anchor_spec, help_id_tour_class,
     HelpAppBase, OnboardingTour, TourBase)
@@ -159,7 +159,7 @@ from ae.kivy_glsl import ShaderIdType, ShadersMixin
 from ae.kivy_relief_canvas import ReliefCanvas                                                          # type: ignore
 
 
-__version__ = '0.3.38'
+__version__ = '0.3.39'
 
 
 # load/declared help/tour widgets, based-on Kivy core widgets (without any features from ae.kivy_app/widgets.kv)
@@ -180,7 +180,14 @@ PropagatedAttributes = Tuple[Any, str, Optional[PosSizeCallable]]
 
 
 class AbsolutePosSizeBinder:
-    """ propagate widget(s) `pos`/`size` changes to attributes/callback, providing absolute window coordinates. """
+    """ propagate changes of `pos`/`size` properties of one or more widgets plus their parents to attributes/callbacks.
+
+    create an instance of this class passing the widget(s) to observe on change of their pos/size. then call the methods
+    :meth:`pos_to_attribute`, :meth:`pos_to_callback`, :meth:`size_to_attribute` and :meth:`size_to_callback` to specify
+    the propagation of the changed `pos` and/or `size`. to remove the change propagation call the method :meth:`unbind`.
+
+    .. note:: the `pos` attribute/callback propagations are providing absolute window coordinates.
+    """
     def __init__(self, *widgets: Widget, bind_window_size: bool = False):
         """ instantiate binder specifying the monitored widget(s).
 
@@ -280,7 +287,7 @@ class AbsolutePosSizeBinder:
 
         :param target:          the object which attribute will be changed on change of `pos`.
         :param attribute:       the name of the attribute to assign the new/changed absolute position.
-        :param converter:       optional pos value converter, return the finally value assigned to the attribute.
+        :param converter:       optional pos value converter, returning the final value assigned to the attribute.
         """
         self._pos_attributes.append((target, attribute, converter))
 
@@ -296,7 +303,7 @@ class AbsolutePosSizeBinder:
 
         :param target:          the object which attribute will be changed on change of `size`.
         :param attribute:       the name of the attribute to assign the new/changed size.
-        :param converter:       optional pos value converter, return the finally value assigned to the attribute.
+        :param converter:       optional pos value converter, returning the final value assigned to the attribute.
         """
         self._size_attributes.append((target, attribute, converter))
 
@@ -325,14 +332,25 @@ class AbsolutePosSizeBinder:
 
 
 class ModalBehavior:                                                                                # pragma: no cover
-    """ mix-in making a container widget modal. """
-    # abstracts provided by the mixing-in container widget
-    center: List
-    close: Callable
-    collide_point: Callable
-    disabled: bool
-    fbind: Callable
-    funbind: Callable
+    """ mix-in to provide a modal mode to a container widget.
+
+    to make the container widget's modal state more obvious, add in your container widget an overlay color with an
+    alpha between 0.3 and 0.9, together with the following canvas instructions:
+
+        canvas:
+            Color:
+                rgba: root.my_overlay_color[:3] + [root.my_overlay_color[-1] if root._window else 0]
+            Rectangle:
+                size: self._window.size if self._window else (0, 0)
+
+    """
+    # abstracts provided by Kivy's :class:`~kivy.uix.widget.Widget` class or by the mixing-in container widget class.
+    center: List                #: center position of :class:`~kivy.uix.widget.Widget`
+    close: Callable             #: method to dismiss the container widget (provided by self/container-widget)
+    collide_point: Callable     #: method to detect collisions with other widgets of :class:`~kivy.uix.widget.Widget`
+    disabled: bool              #: disabled property of :class:`~kivy.uix.widget.Widget`
+    fbind: Callable             #: fast binding method of :class:`~kivy.uix.widget.Widget`
+    funbind: Callable           #: fast unbinding method of :class:`~kivy.uix.widget.Widget`
 
     auto_dismiss = BooleanProperty()
     """ determines if the container is automatically dismissed when the user hits the Esc/Back key or clicks outside it.
@@ -341,20 +359,28 @@ class ModalBehavior:
     """
 
     _fast_bound: List = []                                  #: list of arg tuples for fbind/funbind
-    _touch_started_inside: Optional[bool] = None            #: flag if touch started inside of the container widget
+    _touch_started_inside: Optional[bool] = None            #: flag if touch started inside self (the container widget)
     _window = ObjectProperty(allownone=True, rebind=True)   #: internal flag to store main window instance if open
 
-    def activate_modal(self):
-        """ activate or renew modal mode for the mixing-in container. """
+    def activate_modal(self, align_center: bool = True):
+        """ activate or renew modal mode for the mixing-in container widget.
+
+        :param align_center:    pass False to prevent the automatic alignment of :attr:`center` to
+                                :attr:`~kivy.core.window.Window.center`
+                                on reposition or resize of self or on resize of :class:`~kivy.core.window.Window`.
+        """
         self.deactivate_modal()
 
         Window.add_widget(self)
-        Window.bind(on_resize=self._align_center, on_key_down=self._on_key_down)
+        Window.bind(on_key_down=self._on_key_down)
 
-        fast_bind = self.fbind                                                  # pylint: disable=no-member
-        self._fast_bound = [('center', self._align_center), ('size', self._align_center)]
-        for fast_binding in self._fast_bound:
-            fast_bind(*fast_binding)
+        if align_center:
+            Window.bind(on_resize=self._align_center)
+
+            fast_bind = self.fbind                                                  # pylint: disable=no-member
+            self._fast_bound = [('center', self._align_center), ('size', self._align_center)]
+            for fast_binding in self._fast_bound:
+                fast_bind(*fast_binding)
 
         self._window = Window
 
@@ -365,10 +391,14 @@ class ModalBehavior:
 
     def deactivate_modal(self):
         """ de-activate modal mode for the mixing-in container. """
-        fast_unbind = self.funbind                                              # pylint: disable=no-member
-        for fast_unbinding in self._fast_bound:
-            fast_unbind(*fast_unbinding)
-        self._fast_bound = []
+        if self._fast_bound:
+            fast_unbind = self.funbind                                              # pylint: disable=no-member
+            for fast_unbinding in self._fast_bound:
+                fast_unbind(*fast_unbinding)
+            self._fast_bound = []
+
+            if self._window:
+                Window.unbind(on_resize=self._align_center)
 
         if self._window:
             Window.unbind(on_resize=self._align_center, on_key_down=self._on_key_down)
@@ -403,6 +433,7 @@ class ModalBehavior:
     def on_touch_move(self, touch):
         """ touch move event handler. """
         if not self.auto_dismiss or self._touch_started_inside:
+            # noinspection PyUnresolvedReferences
             super().on_touch_move(touch)    # pylint: disable=no-member # false positive
         return True
 
@@ -411,6 +442,7 @@ class ModalBehavior:
         if self.auto_dismiss and self._touch_started_inside is False:
             self.close()
         else:
+            # noinspection PyUnresolvedReferences
             super().on_touch_up(touch)      # pylint: disable=no-member # false positive
         self._touch_started_inside = None
         return True
@@ -451,7 +483,7 @@ class Tooltip(ScrollView):
         return anchor_layout_x(anc, self.width, win_w), anchor_layout_y(anc, self.height, win_h)
 
     def collide_tap_thru_toggler(self, touch_x: float, touch_y: float) -> bool:
-        """ check if touch is on the tap thru toggler pseudo button.
+        """ check if touch is on the tap through toggler pseudo button.
 
         :param touch_x:         window x position of touch.
         :param touch_y:         window y position of touch.
@@ -467,11 +499,11 @@ class Tooltip(ScrollView):
         return min_x <= touch_x < max_x and min_y <= touch_y < max_y
 
     def collide_tour_start_button(self, touch_x: float, touch_y: float) -> bool:
-        """ check if touch is on the tap thru toggler pseudo button.
+        """ check if touch is on the tap through toggler pseudo button.
 
         :param touch_x:         window x position of touch.
         :param touch_y:         window y position of touch.
-        :return:                True if user touched the tap thru toggler.
+        :return:                True if user touched the tap through toggler.
         """
         min_x, min_y = self.tour_start_pos
         width, height = self.tour_start_size
@@ -568,11 +600,11 @@ class HelpBehavior:
 class HelpToggler(ReliefCanvas, Image):                                                               # pragma: no cover
     """ widget to activate and deactivate the help mode.
 
-    To prevent the dismiss of opened popups and dropdowns at help mode activation, this singleton instance has to:
+    To prevent dismiss of opened popups and dropdowns at help mode activation, this singleton instance has to:
 
     * be registered in its __init__ to the :attr:`~ae.gui_help.HelpAppBase.help_activator` attribute and
     * have a :meth:`~HelpToggler.on_touch_down` method that is eating the activation touch event (returning True) and
-    * a :meth:`~HelpToggler.on_touch_down` method not passing a activation touch in all DropDown/Popup widgets.
+    * a :meth:`~HelpToggler.on_touch_down` method not passing an activation touch in all DropDown/Popup widgets.
 
     """
     ani_value = NumericProperty(0.999)      #: float value (range: 0.0 - 1.0) to animate this button in help/tour mode
@@ -805,7 +837,7 @@ class AnimatedTourMixin:        # (TourBase):
         self._add_animations(self.pages_animations.get(None, ()) + self.pages_animations.get(page_id, ()))
 
     def setup_layout(self):
-        """ overridden to setup animations and shaders of the current tour page. """
+        """ overridden to set up animations and shaders of the current tour page. """
         # noinspection PyUnresolvedReferences
         super().setup_layout()                                                              # pylint: disable=no-member
         Clock.tick()                # update position of explained widget
@@ -836,7 +868,7 @@ class AnimatedTourMixin:        # (TourBase):
 
     def tap_animation(self, wid_id: str = '', pos_delay: float = 2.34,
                       press_delay: float = 0.69, release_delay: float = 0.39) -> PageAnimationType:
-        """ create an compound animation instance simulating a user touch/tap on the specified widget.
+        """ create a compound animation instance simulating a user touch/tap on the specified widget.
 
         :param wid_id:          specifies the widget to be tap simulated: either a widget id string (first item of the
                                 :data:`PageAnimationType` tuple), or (if prefixed with a column character) tap/focus/
